@@ -21,19 +21,20 @@ class lprefix(Unit):
         self,
         prefix: arg(nargs='?', type=str,
             help='Choose a Python format string to extract the prefix, default is "{default}".') = 'L',
-        limit: arg.number('limit', metavar='limit',
-            help='Only decode up to a given number of chunks and treat the rest as leftover data.') = INF,
-        strict: arg.switch('-t', help='Discard any leftover data with invalid length prefix.') = False,
+        limit : arg.number('-L', help='Only decode up to {varname} chunks and treat the rest as leftover data.') = INF,
+        strict: arg.switch('-S', help='Discard any leftover data with invalid length prefix.') = False,
+        single: arg.switch('-s', help='Equivalent to --strict --limit=1.') = False,
         header: arg('-H', action='count', default=0, help=(
-            'Treat the parsed prefix as part of the body. Specify twice to automatically add the size of '
-            'the prefix to the calculated length (i.e. the parsed length from the header specifies the '
-            'length of the chunk body, but the output should include both head and body.'
+            'Treat the parsed prefix as part of the body. Specify twice to strip the header afterwards.'
         )) = 0,
         derive: arg('-d', metavar='d(N)', type=str, help=(
             'Provide an arithmetic Python expression involving the variable N which represents the length '
             'prefix that was read. The value of this expression is used as the actual number of bytes. '
             'The default expression is "N".')) = None
     ):
+        if single:
+            strict = True
+            limit = 1
         if not prefix:
             raise ValueError('an empty prefix was specified')
         if prefix[0] not in '<!=@>':
@@ -58,8 +59,8 @@ class lprefix(Unit):
         parse = PythonExpression(self.args.derive or 'N', 'N', *meta)
         hsize = calcsize(self.args.prefix) if self.args.header > 1 else 0
         with StructReader(memoryview(data)) as mf:
+            count = size = position = 0
             try:
-                count = size = 0
                 while not mf.eof:
                     position = mf.tell()
                     if count >= self.args.limit:
@@ -67,15 +68,18 @@ class lprefix(Unit):
                     size = mf.read_struct(self.args.prefix, unwrap=True)
                     size = parse(N=size, **meta)
                     if self.args.header:
-                        size += hsize
-                        mf.seek(position)
+                        if self.args.header > 1:
+                            size -= hsize
+                        else:
+                            size += hsize
+                            mf.seek(position)
                     self.log_info(F'reading chunk of size: {size}')
                     yield mf.read(size)
                     count += 1
             except EOF as eof:
-                if len(eof.rest) < size:
-                    self.log_info(F'attempted to read 0x{size:X} bytes, got only 0x{len(eof.rest):X}.')
-                if self.args.strict:
+                if self.args.strict or count >= self.args.limit:
                     return
+                if len(eof.rest) < size:
+                    self.log_warn(F'attempted to read 0x{size:X} bytes, got only 0x{len(eof.rest):X}.')
                 mf.seek(position)
                 yield mf.read()
